% Copyright (c) Jupyter Development Team.

% Distributed under the terms of the Modified BSD License.

(file-editor)=

# Text Editor

The text editor in JupyterLab enables you to edit text files in
JupyterLab:

```{image} ../images/file-editor-overview.png
:align: center
:class: jp-screenshot
```

The text editor includes syntax highlighting, configurable indentation
(tabs or spaces) and
basic theming. These settings can be found in the Settings menu:

```{image} ../images/file-editor-settings.png
:align: center
:class: jp-screenshot
```

(edit-existing-file)=

To edit an existing text file, double-click on its name in the file
browser or drag it into the main work area:

```{raw} html
<div class="jp-youtube-video">
  <iframe src="https://www.youtube-nocookie.com/embed/IuqmxkHsS7o?rel=0&amp;showinfo=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
</div>
```

(create-file-button)=

To create a new text file in the current folder of the file browser,
click the `+` button at the top of the file browser to create a new
Launcher tab, and click the “Text Editor” card in the Launcher:

```{raw} html
<div class="jp-youtube-video">
  <iframe src="https://www.youtube-nocookie.com/embed/T1XVz-rjW8I?rel=0&amp;showinfo=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
</div>
```

(create-file-menu)=

You can also create a new text file with the File menu:

```{raw} html
<div class="jp-youtube-video">
  <iframe src="https://www.youtube-nocookie.com/embed/ssFCduQAF48?rel=0&amp;showinfo=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
</div>
```

(rename-file)=

A new file is created with a default name. Rename a file by
right-clicking on its name in the file browser and selecting “Rename”
from the context menu:

```{raw} html
<div class="jp-youtube-video">
  <iframe src="https://www.youtube-nocookie.com/embed/pQR0RV9ObnQ?rel=0&amp;showinfo=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
</div>
```
